@@ -1,6 +1,6 @@
 /* defs.h -- data types and declarations.
    Copyright (C) 1990, 1991, 1992, 1993, 1994, 2000, 2004, 2005, 2006,
-                 2007, 2008, 2009 Free Software Foundation, Inc.
+   2007, 2008, 2009, 2010 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -672,7 +672,5 @@ struct state
 extern struct state state;
 extern char const *starting_dir;
 extern int starting_desc;
-extern char *program_name;
-
 
 #endif
