@@ -1,6 +1,6 @@
 /* finddata.c -- global data for "find".
-   Copyright (C) 1990, 91, 92, 93, 94, 2000,
-                 2003, 2004, 2005, 2007 Free Software Foundation, Inc.
+   Copyright (C) 1990, 1991, 1992, 1993, 1994, 2000, 2003, 2004, 2005,
+   2007, 2010 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -21,9 +21,6 @@
 #include "defs.h"
 
 
-/* Name this program was run with. */
-char *program_name;
-
 struct options options;
 struct state state;
 
